@@ -2,50 +2,60 @@ package IPC::SRLock;
 
 use 5.010001;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.24.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.25.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
+use File::DataClass::Types qw( HashRef LoadableClass NonEmptySimpleStr Object );
 use Moo;
-use File::DataClass::Types  qw( HashRef LoadableClass Object );
-use Type::Utils             qw( enum );
 
-my $Lock_Type = enum 'Lock_Type' => [ qw( fcntl memcached sysv ) ];
+my $_build__implementation = sub {
+   my $self = shift; my $name = lc join '_', split m{ :: }mx, __PACKAGE__, -1;
+
+   my $attr = { name => $name, %{ $self->_implementation_attr }, };
+
+   return $self->_implementation_class->new( $attr );
+};
+
+my $_build__implementation_class = sub {
+   my $self = shift; my $type = $self->type; my $class;
+
+   if (substr $type, 0, 1 eq '+') { $class = substr $type, 1 }
+   else { $class = __PACKAGE__.'::'.(ucfirst $type) }
+
+   return $class;
+};
 
 # Public attributes
-has 'type'                  => is => 'ro',   isa => $Lock_Type,
-   default                  => 'fcntl';
+has 'type' => is => 'ro', isa => NonEmptySimpleStr, default => 'fcntl';
 
 # Private attributes
-has '_implementation'       => is => 'lazy', isa => Object, builder => sub {
-   $_[ 0 ]->_implementation_class->new( $_[ 0 ]->_get_attr ) },
+has '_implementation'       => is => 'lazy', isa => Object,
    handles                  => [ qw( debug get_table list reset set ) ],
-   init_arg                 => undef;
+   builder                  => $_build__implementation;
 
 has '_implementation_attr'  => is => 'ro',   isa => HashRef,
    default                  => sub { {} };
 
 has '_implementation_class' => is => 'lazy', isa => LoadableClass,
-   builder                  => sub { __PACKAGE__.'::'.(ucfirst $_[ 0 ]->type) },
-   init_arg                 => undef;
+   builder                  => $_build__implementation_class;
 
 # Construction
 around 'BUILDARGS' => sub {
-   my ($next, $self, @args) = @_; my $attr = $self->$next( @args );
+   my ($orig, $self, @args) = @_; my $attr = $orig->( $self, @args );
 
-   my $type = delete $attr->{type}; $attr = { _implementation_attr => $attr };
+   my $type = delete $attr->{type};
 
-   $type and $attr->{type} = $type; return $attr;
+   $attr = { _implementation_attr => $attr }; $type or return $attr;
+
+   if ($type =~ m{ \A ([a-zA-Z0-9\:\+]+) \z }mx) { $attr->{type} = $1 }
+   else { die "Type ${type} tainted" }
+
+   return $attr;
 };
 
 sub BUILD {
    my $self = shift; $self->_implementation; return;
 }
 
-# Private methods
-sub _get_attr {
-   return { name => (lc join '_', split m{ :: }mx, __PACKAGE__),
-            %{ $_[ 0 ]->_implementation_attr }, };
-}
-
 1;
 
 __END__
@@ -54,13 +64,21 @@ __END__
 
 =encoding utf8
 
+=begin html
+
+<a href="https://travis-ci.org/pjfl/p5-ipc-srlock"><img src="https://travis-ci.org/pjfl/p5-ipc-srlock.svg?branch=master" alt="Travis CI Badge"></a>
+<a href="http://badge.fury.io/pl/IPC-SRLock"><img src="https://badge.fury.io/pl/IPC-SRLock.svg" alt="CPAN Badge"></a>
+<a href="http://cpants.cpanauthors.org/dist/IPC-SRLock"><img src="http://cpants.cpanauthors.org/dist/IPC-SRLock.png" alt="Kwalitee Badge"></a>
+
+=end html
+
 =head1 Name
 
 IPC::SRLock - Set/reset locking semantics to single thread processes
 
 =head1 Version
 
-This documents version v0.24.$Rev: 1 $ of L<IPC::SRLock>
+This documents version v0.25.$Rev: 1 $ of L<IPC::SRLock>
 
 =head1 Synopsis
 
@@ -95,7 +113,7 @@ Defines the following attributes;
 
 =item C<debug>
 
-Mutable attribute if true will log lock set events at the debug level
+Immutable attribute if true will log lock set events at the debug level
 
 =item C<type>
 
