@@ -2,75 +2,64 @@ package IPC::SRLock::Fcntl;
 
 use namespace::autoclean;
 
-use Moo;
 use English                    qw( -no_match_vars );
 use File::DataClass::Constants qw( LOCK_BLOCKING LOCK_NONBLOCKING );
 use File::DataClass::Types     qw( Directory NonEmptySimpleStr
-                                   Path PositiveInt RegexpRef );
+                                   OctalNum Path PositiveInt RegexpRef );
 use File::Spec;
+use IPC::SRLock::Functions     qw( Unspecified hash_from set_args );
 use Storable                   qw( nfreeze thaw );
 use Time::HiRes                qw( usleep );
 use Try::Tiny;
+use Moo;
 
 extends q(IPC::SRLock::Base);
 
+# Attribute constructors
+my $_build__lockfile = sub {
+   my $self = shift; my $path = $self->_lockfile_name;
+
+   $path ||= $self->tempdir->catfile( $self->name.'.lck' );
+   $path =~ $self->pattern
+      or $self->throw( 'Path [_1] cannot untaint', [ $path ] );
+   return $path;
+};
+
+my $_build__shmfile = sub {
+   my $self = shift; my $path = $self->_shmfile_name;
+
+   $path ||= $self->tempdir->catfile( $self->name.'.shm' );
+   $path =~ $self->pattern
+      or $self->throw( 'Path [_1] cannot untaint', [ $path ] );
+   return $path;
+};
+
 # Public attributes
-has 'mode'    => is => 'ro', isa => PositiveInt, default => oct '0666';
+has 'mode'    => is => 'ro', isa => OctalNum, coerce => 1, default => '0666';
 
 has 'pattern' => is => 'ro', isa => RegexpRef,
    default    => sub { qr{ \A ([ ~:+./\-\\\w]+) \z }msx };
 
-has 'tempdir' => is => 'ro', isa => Directory, coerce => Directory->coercion,
+has 'tempdir' => is => 'ro', isa => Directory, coerce => 1,
    default    => sub { File::Spec->tmpdir };
 
 has 'umask'   => is => 'ro', isa => PositiveInt, default => 0;
 
 # Private attributes
-has '_lockfile'      => is => 'lazy', isa => Path, coerce => Path->coercion;
+has '_lockfile'      => is => 'lazy', isa => Path, coerce => 1,
+   builder           => $_build__lockfile;
 
 has '_lockfile_name' => is => 'ro',   isa => NonEmptySimpleStr,
    init_arg          => 'lockfile';
 
-has '_shmfile'       => is => 'lazy', isa => Path, coerce => Path->coercion;
+has '_shmfile'       => is => 'lazy', isa => Path, coerce => 1,
+   builder           => $_build__shmfile;
 
 has '_shmfile_name'  => is => 'ro',   isa => NonEmptySimpleStr,
    init_arg          => 'shmfile';
 
 # Private methods
-sub _build__lockfile {
-   my $self = shift; my $path = $self->_lockfile_name;
-
-   $path ||= $self->tempdir->catfile( $self->name.'.lck' );
-   $path =~ $self->pattern
-      or $self->throw( 'Path [_1] cannot untaint', args => [ $path ] );
-   return $path;
-}
-
-sub _build__shmfile {
-   my $self = shift; my $path = $self->_shmfile_name;
-
-   $path ||= $self->tempdir->catfile( $self->name.'.shm' );
-   $path =~ $self->pattern
-      or $self->throw( 'Path [_1] cannot untaint', args => [ $path ] );
-   return $path;
-}
-
-sub _list {
-   my $self = shift; my $list = [];
-
-   my ($lock_file, $shm_content) = $self->_read_shmfile; $lock_file->close;
-
-   while (my ($key, $info) = each %{ $shm_content }) {
-      push @{ $list }, { key     => $key,
-                         pid     => $info->{spid},
-                         stime   => $info->{stime},
-                         timeout => $info->{timeout} };
-   }
-
-   return $list;
-}
-
-sub _read_shmfile {
+my $_read_shmfile = sub {
    my ($self, $async) = @_; my ($file, $content);
 
    my $old_umask = umask $self->umask;
@@ -90,27 +79,58 @@ sub _read_shmfile {
 
    $shmfile->close; umask $old_umask;
    return ($file, $content);
+};
+
+my $_write_shmfile = sub {
+   my ($self, $file, $content) = @_; my $wtr;
+
+   try   { $wtr = $self->_shmfile->assert_open( 'w', $self->mode ) }
+   catch { $file->close; $self->throw( $_ ) };
+
+   try   { $wtr->print( nfreeze $content ) }
+   catch { $wtr->delete; $file->close; $self->throw( $_ ) };
+
+   $wtr->close; $file->close;
+   return;
+};
+
+# Public methods
+sub list {
+   my $self = shift; my $list = [];
+
+   my ($lock_file, $shm_content) = $self->$_read_shmfile; $lock_file->close;
+
+   while (my ($key, $info) = each %{ $shm_content }) {
+      push @{ $list }, { key     => $key,
+                         pid     => $info->{spid},
+                         stime   => $info->{stime},
+                         timeout => $info->{timeout} };
+   }
+
+   return $list;
 }
 
-sub _reset {
-   my ($self, $key) = @_; my $found;
-
-   my ($lock_file, $shm_content) = $self->_read_shmfile;
+sub reset {
+   my $self = shift;
+   my $args = hash_from @_;
+   my $key  = $args->{k} or $self->throw( Unspecified, [ 'key' ] );
+   my ($lock_file, $shm_content) = $self->$_read_shmfile; $key = "${key}";
+   my $found;
 
    $found = exists $shm_content->{ $key } and delete $shm_content->{ $key };
-   $found and $self->_write_shmfile( $lock_file, $shm_content );
+   $found and $self->$_write_shmfile( $lock_file, $shm_content );
    $lock_file->close;
-   $found or $self->throw( 'Lock [_1] not set', args => [ $key ] );
+   $found or $self->throw( 'Lock [_1] not set', [ $key ] );
    return 1;
 }
 
-sub _set {
-   my ($self, $args) = @_; my $start = time;
+sub set {
+   my $self = shift; my $args = set_args $self, @_; my $start = time;
 
    my $key = $args->{k}; my $pid = $args->{p}; my $timeout = $args->{t};
 
    while (1) {
-      my ($lock_file, $shm_content) = $self->_read_shmfile( $args->{async} );
+      my ($lock_file, $shm_content) = $self->$_read_shmfile( $args->{async} );
 
       my $now = time; my $lock;
 
@@ -128,7 +148,7 @@ sub _set {
          unless ($lock) {
             $shm_content->{ $key }
                = { spid => $pid, stime => $now, timeout => $timeout };
-            $self->_write_shmfile( $lock_file, $shm_content );
+            $self->$_write_shmfile( $lock_file, $shm_content );
             $self->log->debug( "Lock ${key} set by ${pid}" );
             return 1;
          }
@@ -137,7 +157,7 @@ sub _set {
       $lock_file->close; $args->{async} and return 0;
 
       $self->patience and $now > $start + $self->patience
-         and $self->throw( 'Lock [_1] timed out', args => [ $key ] );
+         and $self->throw( 'Lock [_1] timed out', [ $key ] );
 
       usleep( 1_000_000 * $self->nap_time );
    }
@@ -145,19 +165,6 @@ sub _set {
    return; # Not reached
 }
 
-sub _write_shmfile {
-   my ($self, $file, $content) = @_; my $wtr;
-
-   try   { $wtr = $self->_shmfile->assert_open( 'w', $self->mode ) }
-   catch { $file->close; $self->throw( $_ ) };
-
-   try   { $wtr->print( nfreeze $content ) }
-   catch { $wtr->delete; $file->close; $self->throw( $_ ) };
-
-   $wtr->close; $file->close;
-   return;
-}
-
 1;
 
 __END__
@@ -217,7 +224,7 @@ The umask to set when creating the lock table file. Defaults to 0
 
 =head1 Subroutines/Methods
 
-=head2 _list
+=head2 list
 
 List the contents of the lock table
 
@@ -225,11 +232,11 @@ List the contents of the lock table
 
 Read the file containing the lock table from disk
 
-=head2 _reset
+=head2 reset
 
 Delete a lock from the lock table
 
-=head2 _set
+=head2 set
 
 Set a lock in the lock table
 
