@@ -2,10 +2,12 @@ package IPC::SRLock::Memcached;
 
 use namespace::autoclean;
 
-use Moo;
 use Cache::Memcached;
+use English                qw( -no_match_vars );
 use File::DataClass::Types qw( ArrayRef NonEmptySimpleStr Object );
+use IPC::SRLock::Functions qw( Unspecified hash_from set_args );
 use Time::HiRes            qw( usleep );
+use Moo;
 
 extends q(IPC::SRLock::Base);
 
@@ -18,14 +20,24 @@ has 'servers'  => is => 'ro', isa => ArrayRef,
 has 'shmfile'  => is => 'ro', isa => NonEmptySimpleStr, default => '_shmfile';
 
 # Private attributes
-has '_memd'    => is => 'lazy', isa => Object, builder => sub {
-   Cache::Memcached->new( debug     => $_[ 0 ]->debug,
-                          namespace => $_[ 0 ]->name,
-                          servers   => $_[ 0 ]->servers ) },
-   init_arg    => undef, reader => 'memd';
+has '_memd'    => is => 'lazy', isa => Object, reader => 'memd',
+   builder     => sub { Cache::Memcached->new
+                           ( debug     => $_[ 0 ]->debug,
+                             namespace => $_[ 0 ]->name,
+                             servers   => $_[ 0 ]->servers ) };
 
 # Private methods
-sub _list {
+my $_sleep_or_throw = sub {
+   my ($self, $start, $now, $key) = @_;
+
+   $self->patience and $now > $start + $self->patience
+      and $self->throw( 'Lock [_1] timed out', [ $key ] );
+   usleep( 1_000_000 * $self->nap_time );
+   return;
+};
+
+# Public methods
+sub list {
    my $self = shift; my $list = []; my $start = time;
 
    while (1) {
@@ -46,14 +58,18 @@ sub _list {
          return $list;
       }
 
-      $self->_sleep_or_throw( $start, time, $self->lockfile );
+      $self->$_sleep_or_throw( $start, time, $self->lockfile );
    }
 
    return;
 }
 
-sub _reset {
-   my ($self, $key) = @_; my $start = time;
+sub reset {
+   my $self = shift; my $args = hash_from @_; my $start = time;
+
+   my $key = $args->{k} or $self->throw( Unspecified, [ 'key' ] );
+
+   $key = "${key}";
 
    while (1) {
       if ($self->memd->add( $self->lockfile, 1, $self->patience + 30 )) {
@@ -62,18 +78,18 @@ sub _reset {
          delete $recs->{ $key } and $found = 1;
          $found and $self->memd->set( $self->shmfile, $recs );
          $self->memd->delete( $self->lockfile );
-         $found or $self->throw( 'Lock [_1] not set', args => [ $key ] );
+         $found or $self->throw( 'Lock [_1] not set', [ $key ] );
          return 1;
       }
 
-      $self->_sleep_or_throw( $start, time, $self->lockfile );
+      $self->$_sleep_or_throw( $start, time, $self->lockfile );
    }
 
    return;
 }
 
-sub _set {
-   my ($self, $args) = @_; my $start = time;
+sub set {
+   my $self = shift; my $args = set_args $self, @_; my $start = time;
 
    my $key = $args->{k}; my $pid = $args->{p}; my $timeout = $args->{t};
 
@@ -111,21 +127,12 @@ sub _set {
          elsif ($args->{async}) { return 0 }
       }
 
-      $self->_sleep_or_throw( $start, $now, $self->lockfile );
+      $self->$_sleep_or_throw( $start, $now, $self->lockfile );
    }
 
    return;
 }
 
-sub _sleep_or_throw {
-   my ($self, $start, $now, $key) = @_;
-
-   $self->patience and $now > $start + $self->patience
-      and $self->throw( 'Lock [_1] timed out', args => [ $key ] );
-   usleep( 1_000_000 * $self->nap_time );
-   return;
-}
-
 1;
 
 __END__
@@ -170,15 +177,15 @@ Name of the key to the lock table record. Defaults to C<_shmfile>
 
 =head1 Subroutines/Methods
 
-=head2 _list
+=head2 list
 
 List the contents of the lock table
 
-=head2 _reset
+=head2 reset
 
 Delete a lock from the lock table
 
-=head2 _set
+=head2 set
 
 Set a lock in the lock table
 
