@@ -2,45 +2,59 @@ package IPC::SRLock::Sysv;
 
 use namespace::autoclean;
 
-use Moo;
 use English                qw( -no_match_vars );
-use File::DataClass::Types qw( NonEmptySimpleStr Object PositiveInt );
+use File::DataClass::Types qw( Object OctalNum PositiveInt );
 use IPC::ShareLite         qw( :lock );
+use IPC::SRLock::Functions qw( Unspecified hash_from set_args );
 use Storable               qw( nfreeze thaw );
 use Time::HiRes            qw( usleep );
 use Try::Tiny;
+use Moo;
 
 extends q(IPC::SRLock::Base);
 
-# Public attributes
-has 'lockfile' => is => 'ro',   isa => PositiveInt,       default  => 12244237;
-
-has 'mode'     => is => 'ro',   isa => NonEmptySimpleStr, default  => '0666';
-
-has 'size'     => is => 'ro',   isa => PositiveInt,       default  => 65_536;
-
-# Private attributes
-has '_share'   => is => 'lazy', isa => Object,            init_arg => undef;
-
-# Construction
-sub BUILD {
-   my $self = shift; $self->_share; return;
-}
-
-# Private methods
-sub _build__share {
+# Attribute constructors
+my $_build__share = sub {
    my $self = shift; my $share;
 
    try   { $share = IPC::ShareLite->new( '-key'    => $self->lockfile,
                                          '-create' => 1,
-                                         '-mode'   => oct $self->mode,
+                                         '-mode'   => $self->mode,
                                          '-size'   => $self->size ) }
    catch { $self->throw( "${_}: ${OS_ERROR}" ) };
 
    return $share;
-}
+};
 
-sub _fetch_share_data {
+# Public attributes
+has 'lockfile' => is => 'ro',   isa => PositiveInt, default => 12_244_237;
+
+has 'mode'     => is => 'ro',   isa => OctalNum, coerce => 1, default => '0666';
+
+has 'size'     => is => 'ro',   isa => PositiveInt, default => 65_536;
+
+# Private attributes
+has '_share'   => is => 'lazy', isa => Object, builder => $_build__share;
+
+# Private functions
+my $_store_share_data = sub {
+   my ($self, $data) = @_;
+
+   try   { $self->_share->store( nfreeze $data ) }
+   catch { $self->throw( "${_}: ${OS_ERROR}" ) };
+
+   return 1;
+};
+
+my $_unlock_share = sub {
+   my $self = shift;
+
+   defined $self->_share->unlock or $self->throw( 'Failed to unset semaphore' );
+
+   return;
+};
+
+my $_fetch_share_data = sub {
    my ($self, $for_update, $async) = @_; my $data;
 
    my $mode = $for_update ? LOCK_EX : LOCK_SH; $async and $mode |= LOCK_NB;
@@ -51,12 +65,18 @@ sub _fetch_share_data {
    try   { $data = $self->_share->fetch; $data = $data ? thaw( $data ) : {} }
    catch { $self->throw( "${_}: ${OS_ERROR}" ) };
 
-   not $for_update and $self->_unlock_share;
+   not $for_update and $self->$_unlock_share;
    return $data;
+};
+
+# Construction
+sub BUILD {
+   my $self = shift; $self->_share; return;
 }
 
-sub _list {
-   my $self = shift; my $data = $self->_fetch_share_data; my $list = [];
+# Public methods
+sub list {
+   my $self = shift; my $data = $self->$_fetch_share_data; my $list = [];
 
    while (my ($key, $info) = each %{ $data }) {
       push @{ $list }, { key     => $key,
@@ -68,25 +88,28 @@ sub _list {
    return $list;
 }
 
-sub _reset {
-   my ($self, $key) = @_; my $data = $self->_fetch_share_data( 1 );
-
-   my $found = delete $data->{ $key } and $self->_store_share_data( $data );
-
-   $self->_unlock_share;
+sub reset {
+   my $self  = shift;
+   my $args  = hash_from @_;
+   my $key   = $args->{k} or $self->throw( Unspecified, [ 'key' ] );
+   my $data  = $self->$_fetch_share_data( 1 ); $key = "${key}";
+   my $found = delete $data->{ $key } and $self->$_store_share_data( $data );
 
+   $self->$_unlock_share;
    $found or $self->throw( 'Lock [_1] not set', args => [ $key ] );
    return 1;
 }
 
-sub _set {
-   my ($self, $args) = @_; my $lock_set; my $start = time;
+sub set {
+   my $self = shift; my $args = set_args $self, @_; my $start = time;
 
    my $key = $args->{k}; my $pid = $args->{p}; my $timeout = $args->{t};
 
+   my $lock_set;
+
    while (not $lock_set) {
       my ($lock, $lpid, $ltime, $ltimeout);
-      my $data  = $self->_fetch_share_data( 1, $args->{async} );
+      my $data  = $self->$_fetch_share_data( 1, $args->{async} );
       my $found = 0; my $now = time; my $timedout = 0;
 
       if ($data) {
@@ -99,7 +122,7 @@ sub _set {
                $data->{ $key } = { pid     => $pid,
                                    stime   => $now,
                                    timeout => $timeout };
-               $lock_set = $self->_store_share_data( $data );
+               $lock_set = $self->$_store_share_data( $data );
                $timedout = 1;
             }
             else { $found = 1 }
@@ -108,10 +131,10 @@ sub _set {
             $data->{ $key } = { pid     => $pid,
                                 stime   => $now,
                                 timeout => $timeout };
-            $lock_set = $self->_store_share_data( $data );
+            $lock_set = $self->$_store_share_data( $data );
          }
 
-         $self->_unlock_share;
+         $self->$_unlock_share;
       }
 
       not $lock_set and $args->{async} and return 0;
@@ -129,23 +152,6 @@ sub _set {
    return 1;
 }
 
-sub _store_share_data {
-   my ($self, $data) = @_;
-
-   try   { $self->_share->store( nfreeze $data ) }
-   catch { $self->throw( "${_}: ${OS_ERROR}" ) };
-
-   return 1;
-}
-
-sub _unlock_share {
-   my $self = shift;
-
-   defined $self->_share->unlock or $self->throw( 'Failed to unset semaphore' );
-
-   return;
-}
-
 1;
 
 __END__
@@ -194,15 +200,15 @@ Maximum size of a shared memory segment. Defaults to 65_536
 
 Create the shared memory segment at construction time
 
-=head2 _list
+=head2 list
 
 List the contents of the lock table
 
-=head2 _reset
+=head2 reset
 
 Delete a lock from the lock table
 
-=head2 _set
+=head2 set
 
 Set a lock in the lock table
 
